from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class InternalDataCollectionBase:

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_List(self) -> List: ...

    def get_SyncRoot(self) -> object: ...


class AcceptRejectRule:

    def Cascade(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataTable:

    def AcceptChanges(self) -> None: ...

    def BeginInit(self) -> None: ...

    def BeginLoadData(self) -> None: ...

    @property
    def CaseSensitive(self): ...

    @CaseSensitive.setter
    def CaseSensitive(self): ...

    @property
    def ChildRelations(self): ...

    @ChildRelations.setter
    def ChildRelations(self): ...

    def Clear(self) -> None: ...

    def Clone(self) -> DataTable: ...

    def ColumnChanged(self, *args, **kwargs) -> Any: ...

    def ColumnChanging(self, *args, **kwargs) -> Any: ...

    @property
    def Columns(self): ...

    @Columns.setter
    def Columns(self): ...

    def Compute(self, _: str, __: str) -> object: ...

    @property
    def Constraints(self): ...

    @Constraints.setter
    def Constraints(self): ...

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    def Copy(self) -> DataTable: ...

    def CreateDataReader(self) -> DataTableReader: ...

    def CreateInstance(self) -> DataTable: ...

    @property
    def DataSet(self): ...

    @DataSet.setter
    def DataSet(self): ...

    @property
    def DefaultView(self): ...

    @DefaultView.setter
    def DefaultView(self): ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    @property
    def DisplayExpression(self): ...

    @DisplayExpression.setter
    def DisplayExpression(self): ...

    def Dispose(self, _: bool) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    def EndInit(self) -> None: ...

    def EndLoadData(self) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Events(self): ...

    @Events.setter
    def Events(self): ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetChanges(self, _: DataRowState) -> DataTable: ...

    def GetDataTableSchema(self,
            _: System.Xml.Schema.XmlSchemaSet,
            ) -> System.Xml.Schema.XmlSchemaComplexType: ...

    def GetErrors(self) -> List[List]: ...

    def GetHashCode(self) -> int: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetRowType(self) -> Type: ...

    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...

    def GetService(self, _: Type) -> object: ...

    def GetType(self) -> Type: ...

    @property
    def HasErrors(self): ...

    @HasErrors.setter
    def HasErrors(self): ...

    def ImportRow(self, _: List) -> None: ...

    def Initialized(self, *args, **kwargs) -> Any: ...

    @property
    def IsInitialized(self): ...

    @IsInitialized.setter
    def IsInitialized(self): ...

    def Load(self,
            _: IDataReader,
            __: LoadOption,
            ___: FillErrorEventHandler,
            ) -> None: ...

    def LoadDataRow(self, _: List[object], __: bool) -> List: ...

    @property
    def Locale(self): ...

    @Locale.setter
    def Locale(self): ...

    def MemberwiseClone(self) -> object: ...

    def Merge(self,
            _: DataTable,
            __: bool,
            ___: MissingSchemaAction,
            ) -> None: ...

    @property
    def MinimumCapacity(self): ...

    @MinimumCapacity.setter
    def MinimumCapacity(self): ...

    @property
    def Namespace(self): ...

    @Namespace.setter
    def Namespace(self): ...

    def NewRow(self) -> List: ...

    def NewRowArray(self, _: int) -> List[List]: ...

    def NewRowFromBuilder(self, _: DataRowBuilder) -> List: ...

    def OnColumnChanged(self, _: Any) -> None: ...

    def OnColumnChanging(self, _: Any) -> None: ...

    def OnPropertyChanging(self,
            _: System.ComponentModel.PropertyChangedEventArgs,
            ) -> None: ...

    def OnRemoveColumn(self, _: List) -> None: ...

    def OnRowChanged(self, _: DataRowChangeEventArgs) -> None: ...

    def OnRowChanging(self, _: DataRowChangeEventArgs) -> None: ...

    def OnRowDeleted(self, _: DataRowChangeEventArgs) -> None: ...

    def OnRowDeleting(self, _: DataRowChangeEventArgs) -> None: ...

    def OnTableCleared(self, _: DataTableClearEventArgs) -> None: ...

    def OnTableClearing(self, _: DataTableClearEventArgs) -> None: ...

    def OnTableNewRow(self, _: DataTableNewRowEventArgs) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def ParentRelations(self): ...

    @ParentRelations.setter
    def ParentRelations(self): ...

    @property
    def Prefix(self): ...

    @Prefix.setter
    def Prefix(self): ...

    @property
    def PrimaryKey(self): ...

    @PrimaryKey.setter
    def PrimaryKey(self): ...

    def ReadXml(self, _: str) -> XmlReadMode: ...

    def ReadXmlSchema(self, _: str) -> None: ...

    def ReadXmlSerializable(self, _: System.Xml.XmlReader) -> None: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RejectChanges(self) -> None: ...

    @property
    def RemotingFormat(self): ...

    @RemotingFormat.setter
    def RemotingFormat(self): ...

    def Reset(self) -> None: ...

    def RowChanged(self, *args, **kwargs) -> Any: ...

    def RowChanging(self, *args, **kwargs) -> Any: ...

    def RowDeleted(self, *args, **kwargs) -> Any: ...

    def RowDeleting(self, *args, **kwargs) -> Any: ...

    @property
    def Rows(self): ...

    @Rows.setter
    def Rows(self): ...

    def Select(self, _: str, __: str, ___: DataViewRowState) -> List[List]: ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    def TableCleared(self, *args, **kwargs) -> Any: ...

    def TableClearing(self, *args, **kwargs) -> Any: ...

    @property
    def TableName(self): ...

    @TableName.setter
    def TableName(self): ...

    def TableNewRow(self, *args, **kwargs) -> Any: ...

    def ToString(self) -> str: ...

    def WriteXml(self, _: str, __: XmlWriteMode, ___: bool) -> None: ...

    def WriteXmlSchema(self, _: str, __: bool) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_ColumnChanged(self, _: DataColumnChangeEventHandler) -> None: ...

    def add_ColumnChanging(self, _: DataColumnChangeEventHandler) -> None: ...

    def add_Disposed(self, _: Any) -> None: ...

    def add_Initialized(self, _: Any) -> None: ...

    def add_RowChanged(self, _: DataRowChangeEventHandler) -> None: ...

    def add_RowChanging(self, _: DataRowChangeEventHandler) -> None: ...

    def add_RowDeleted(self, _: DataRowChangeEventHandler) -> None: ...

    def add_RowDeleting(self, _: DataRowChangeEventHandler) -> None: ...

    def add_TableCleared(self, _: DataTableClearEventHandler) -> None: ...

    def add_TableClearing(self, _: DataTableClearEventHandler) -> None: ...

    def add_TableNewRow(self, _: DataTableNewRowEventHandler) -> None: ...

    def get_CaseSensitive(self) -> bool: ...

    def get_ChildRelations(self) -> DataRelationCollection: ...

    def get_Columns(self) -> DataColumnCollection: ...

    def get_Constraints(self) -> ConstraintCollection: ...

    def get_Container(self) -> System.ComponentModel.IContainer: ...

    def get_DataSet(self) -> DataSet: ...

    def get_DefaultView(self) -> DataView: ...

    def get_DesignMode(self) -> bool: ...

    def get_DisplayExpression(self) -> str: ...

    def get_Events(self) -> System.ComponentModel.EventHandlerList: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_HasErrors(self) -> bool: ...

    def get_IsInitialized(self) -> bool: ...

    def get_Locale(self) -> System.Globalization.CultureInfo: ...

    def get_MinimumCapacity(self) -> int: ...

    def get_Namespace(self) -> str: ...

    def get_ParentRelations(self) -> DataRelationCollection: ...

    def get_Prefix(self) -> str: ...

    def get_PrimaryKey(self) -> List[List]: ...

    def get_RemotingFormat(self) -> SerializationFormat: ...

    def get_Rows(self) -> DataRowCollection: ...

    def get_Site(self) -> System.ComponentModel.ISite: ...

    def get_TableName(self) -> str: ...

    def remove_ColumnChanged(self,
            _: DataColumnChangeEventHandler,
            ) -> None: ...

    def remove_ColumnChanging(self,
            _: DataColumnChangeEventHandler,
            ) -> None: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def remove_Initialized(self, _: Any) -> None: ...

    def remove_RowChanged(self, _: DataRowChangeEventHandler) -> None: ...

    def remove_RowChanging(self, _: DataRowChangeEventHandler) -> None: ...

    def remove_RowDeleted(self, _: DataRowChangeEventHandler) -> None: ...

    def remove_RowDeleting(self, _: DataRowChangeEventHandler) -> None: ...

    def remove_TableCleared(self, _: DataTableClearEventHandler) -> None: ...

    def remove_TableClearing(self, _: DataTableClearEventHandler) -> None: ...

    def remove_TableNewRow(self, _: DataTableNewRowEventHandler) -> None: ...

    def set_CaseSensitive(self, _: bool) -> None: ...

    def set_DisplayExpression(self, _: str) -> None: ...

    def set_Locale(self, _: System.Globalization.CultureInfo) -> None: ...

    def set_MinimumCapacity(self, _: int) -> None: ...

    def set_Namespace(self, _: str) -> None: ...

    def set_Prefix(self, _: str) -> None: ...

    def set_PrimaryKey(self, _: List[List]) -> None: ...

    def set_RemotingFormat(self, _: SerializationFormat) -> None: ...

    def set_Site(self, _: System.ComponentModel.ISite) -> None: ...

    def set_TableName(self, _: str) -> None: ...


class DataTableReader:

    def Close(self) -> None: ...

    def CreateObjRef(self, _: Type) -> System.Runtime.Remoting.ObjRef: ...

    @property
    def Depth(self): ...

    @Depth.setter
    def Depth(self): ...

    def Dispose(self, _: bool) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def FieldCount(self): ...

    @FieldCount.setter
    def FieldCount(self): ...

    def Finalize(self) -> None: ...

    def GetBoolean(self, _: int) -> bool: ...

    def GetByte(self, _: int) -> bytes: ...

    def GetBytes(self,
            _: int,
            __: int,
            ___: List[bytes],
            ____: int,
            _____: int,
            ) -> int: ...

    def GetChar(self, _: int) -> str: ...

    def GetChars(self, _: int, __: int, ___: List[str], ____: int, _____: int) -> int: ...

    def GetData(self, _: int) -> Any: ...

    def GetDataTypeName(self, _: int) -> str: ...

    def GetDateTime(self, _: int) -> System.DateTime: ...

    def GetDbDataReader(self, _: int) -> Any: ...

    def GetDecimal(self, _: int) -> float: ...

    def GetDouble(self, _: int) -> float: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetFieldType(self, _: int) -> Type: ...

    def GetFieldValue(self, *args, **kwargs) -> Any: ...

    def GetFieldValueAsync(self, *args, **kwargs) -> Any: ...

    def GetFloat(self, _: int) -> float: ...

    def GetGuid(self, _: int) -> System.Guid: ...

    def GetHashCode(self) -> int: ...

    def GetInt16(self, _: int) -> int: ...

    def GetInt32(self, _: int) -> int: ...

    def GetInt64(self, _: int) -> int: ...

    def GetLifetimeService(self) -> object: ...

    def GetName(self, _: int) -> str: ...

    def GetOrdinal(self, _: str) -> int: ...

    def GetProviderSpecificFieldType(self, _: int) -> Type: ...

    def GetProviderSpecificValue(self, _: int) -> object: ...

    def GetProviderSpecificValues(self, _: List[object]) -> int: ...

    def GetSchemaTable(self) -> DataTable: ...

    def GetStream(self, _: int) -> System.IO.Stream: ...

    def GetString(self, _: int) -> str: ...

    def GetTextReader(self, _: int) -> System.IO.TextReader: ...

    def GetType(self) -> Type: ...

    def GetValue(self, _: int) -> object: ...

    def GetValues(self, _: List[object]) -> int: ...

    @property
    def HasRows(self): ...

    @HasRows.setter
    def HasRows(self): ...

    def InitializeLifetimeService(self) -> object: ...

    @property
    def IsClosed(self): ...

    @IsClosed.setter
    def IsClosed(self): ...

    def IsDBNull(self, _: int) -> bool: ...

    def IsDBNullAsync(self,
            _: int,
            __: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task[bool]: ...

    def MemberwiseClone(self) -> object: ...

    def NextResult(self) -> bool: ...

    def NextResultAsync(self,
            _: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task[bool]: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Read(self) -> bool: ...

    def ReadAsync(self,
            _: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task[bool]: ...

    @property
    def RecordsAffected(self): ...

    @RecordsAffected.setter
    def RecordsAffected(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def VisibleFieldCount(self): ...

    @VisibleFieldCount.setter
    def VisibleFieldCount(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Depth(self) -> int: ...

    def get_FieldCount(self) -> int: ...

    def get_HasRows(self) -> bool: ...

    def get_IsClosed(self) -> bool: ...

    def get_Item(self, _: str) -> object: ...

    def get_RecordsAffected(self) -> int: ...

    def get_VisibleFieldCount(self) -> int: ...


class DataRowState:

    def Added(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Deleted(self, *args, **kwargs) -> Any: ...

    def Detached(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Modified(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Unchanged(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataRow:

    def AcceptChanges(self) -> None: ...

    def BeginEdit(self) -> None: ...

    def CancelEdit(self) -> None: ...

    def ClearErrors(self) -> None: ...

    def Delete(self) -> None: ...

    def EndEdit(self) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetChildRows(self, _: str, __: DataRowVersion) -> List[List]: ...

    def GetColumnError(self, _: str) -> str: ...

    def GetColumnsInError(self) -> List[List]: ...

    def GetHashCode(self) -> int: ...

    def GetParentRow(self, _: str, __: DataRowVersion) -> List: ...

    def GetParentRows(self, _: str, __: DataRowVersion) -> List[List]: ...

    def GetType(self) -> Type: ...

    @property
    def HasErrors(self): ...

    @HasErrors.setter
    def HasErrors(self): ...

    def HasVersion(self, _: DataRowVersion) -> bool: ...

    def IsNull(self, _: str) -> bool: ...

    @property
    def ItemArray(self): ...

    @ItemArray.setter
    def ItemArray(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RejectChanges(self) -> None: ...

    @property
    def RowError(self): ...

    @RowError.setter
    def RowError(self): ...

    @property
    def RowState(self): ...

    @RowState.setter
    def RowState(self): ...

    def SetAdded(self) -> None: ...

    def SetColumnError(self, _: str, __: str) -> None: ...

    def SetModified(self) -> None: ...

    def SetNull(self, _: List) -> None: ...

    def SetParentRow(self, _: List, __: DataRelation) -> None: ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_HasErrors(self) -> bool: ...

    def get_Item(self, _: str, __: DataRowVersion) -> object: ...

    def get_ItemArray(self) -> List[object]: ...

    def get_RowError(self) -> str: ...

    def get_RowState(self) -> DataRowState: ...

    def get_Table(self) -> DataTable: ...

    def set_Item(self, _: str, __: object) -> None: ...

    def set_ItemArray(self, _: List[object]) -> None: ...

    def set_RowError(self, _: str) -> None: ...


class DataSet:

    def AcceptChanges(self) -> None: ...

    def BeginInit(self) -> None: ...

    @property
    def CaseSensitive(self): ...

    @CaseSensitive.setter
    def CaseSensitive(self): ...

    def Clear(self) -> None: ...

    def Clone(self) -> DataSet: ...

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    def Copy(self) -> DataSet: ...

    def CreateDataReader(self,
            _: List[DataTable],
            ) -> DataTableReader: ...

    @property
    def DataSetName(self): ...

    @DataSetName.setter
    def DataSetName(self): ...

    @property
    def DefaultViewManager(self): ...

    @DefaultViewManager.setter
    def DefaultViewManager(self): ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    def DetermineSchemaSerializationMode(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> SchemaSerializationMode: ...

    def Dispose(self, _: bool) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    def EndInit(self) -> None: ...

    @property
    def EnforceConstraints(self): ...

    @EnforceConstraints.setter
    def EnforceConstraints(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Events(self): ...

    @Events.setter
    def Events(self): ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetChanges(self, _: DataRowState) -> DataSet: ...

    def GetDataSetSchema(self,
            _: System.Xml.Schema.XmlSchemaSet,
            ) -> System.Xml.Schema.XmlSchemaComplexType: ...

    def GetHashCode(self) -> int: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetSchemaSerializable(self) -> System.Xml.Schema.XmlSchema: ...

    def GetSerializationData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetService(self, _: Type) -> object: ...

    def GetType(self) -> Type: ...

    def GetXml(self) -> str: ...

    def GetXmlSchema(self) -> str: ...

    def HasChanges(self, _: DataRowState) -> bool: ...

    @property
    def HasErrors(self): ...

    @HasErrors.setter
    def HasErrors(self): ...

    def InferXmlSchema(self, _: str, __: List[str]) -> None: ...

    def InitializeDerivedDataSet(self) -> None: ...

    def Initialized(self, *args, **kwargs) -> Any: ...

    def IsBinarySerialized(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> bool: ...

    @property
    def IsInitialized(self): ...

    @IsInitialized.setter
    def IsInitialized(self): ...

    def Load(self,
            _: IDataReader,
            __: LoadOption,
            ___: FillErrorEventHandler,
            ____: List[DataTable],
            ) -> None: ...

    @property
    def Locale(self): ...

    @Locale.setter
    def Locale(self): ...

    def MemberwiseClone(self) -> object: ...

    def Merge(self,
            _: DataTable,
            __: bool,
            ___: MissingSchemaAction,
            ) -> None: ...

    def MergeFailed(self, *args, **kwargs) -> Any: ...

    @property
    def Namespace(self): ...

    @Namespace.setter
    def Namespace(self): ...

    def OnPropertyChanging(self,
            _: System.ComponentModel.PropertyChangedEventArgs,
            ) -> None: ...

    def OnRemoveRelation(self, _: DataRelation) -> None: ...

    def OnRemoveTable(self, _: DataTable) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Prefix(self): ...

    @Prefix.setter
    def Prefix(self): ...

    def RaisePropertyChanging(self, _: str) -> None: ...

    def ReadXml(self, _: str, __: XmlReadMode) -> XmlReadMode: ...

    def ReadXmlSchema(self, _: str) -> None: ...

    def ReadXmlSerializable(self, _: System.Xml.XmlReader) -> None: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RejectChanges(self) -> None: ...

    @property
    def Relations(self): ...

    @Relations.setter
    def Relations(self): ...

    @property
    def RemotingFormat(self): ...

    @RemotingFormat.setter
    def RemotingFormat(self): ...

    def Reset(self) -> None: ...

    @property
    def SchemaSerializationMode(self): ...

    @SchemaSerializationMode.setter
    def SchemaSerializationMode(self): ...

    def ShouldSerializeRelations(self) -> bool: ...

    def ShouldSerializeTables(self) -> bool: ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    @property
    def Tables(self): ...

    @Tables.setter
    def Tables(self): ...

    def ToString(self) -> str: ...

    def WriteXml(self, _: str, __: XmlWriteMode) -> None: ...

    def WriteXmlSchema(self, _: str, __: System.Converter[Type, str]) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_Disposed(self, _: Any) -> None: ...

    def add_Initialized(self, _: Any) -> None: ...

    def add_MergeFailed(self, _: MergeFailedEventHandler) -> None: ...

    def get_CaseSensitive(self) -> bool: ...

    def get_Container(self) -> System.ComponentModel.IContainer: ...

    def get_DataSetName(self) -> str: ...

    def get_DefaultViewManager(self) -> DataViewManager: ...

    def get_DesignMode(self) -> bool: ...

    def get_EnforceConstraints(self) -> bool: ...

    def get_Events(self) -> System.ComponentModel.EventHandlerList: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_HasErrors(self) -> bool: ...

    def get_IsInitialized(self) -> bool: ...

    def get_Locale(self) -> System.Globalization.CultureInfo: ...

    def get_Namespace(self) -> str: ...

    def get_Prefix(self) -> str: ...

    def get_Relations(self) -> DataRelationCollection: ...

    def get_RemotingFormat(self) -> SerializationFormat: ...

    def get_SchemaSerializationMode(self) -> SchemaSerializationMode: ...

    def get_Site(self) -> System.ComponentModel.ISite: ...

    def get_Tables(self) -> DataTableCollection: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def remove_Initialized(self, _: Any) -> None: ...

    def remove_MergeFailed(self, _: MergeFailedEventHandler) -> None: ...

    def set_CaseSensitive(self, _: bool) -> None: ...

    def set_DataSetName(self, _: str) -> None: ...

    def set_EnforceConstraints(self, _: bool) -> None: ...

    def set_Locale(self, _: System.Globalization.CultureInfo) -> None: ...

    def set_Namespace(self, _: str) -> None: ...

    def set_Prefix(self, _: str) -> None: ...

    def set_RemotingFormat(self, _: SerializationFormat) -> None: ...

    def set_SchemaSerializationMode(self,
            _: SchemaSerializationMode,
            ) -> None: ...

    def set_Site(self, _: System.ComponentModel.ISite) -> None: ...


class DataColumn:

    @property
    def AllowDBNull(self): ...

    @AllowDBNull.setter
    def AllowDBNull(self): ...

    @property
    def AutoIncrement(self): ...

    @AutoIncrement.setter
    def AutoIncrement(self): ...

    @property
    def AutoIncrementSeed(self): ...

    @AutoIncrementSeed.setter
    def AutoIncrementSeed(self): ...

    @property
    def AutoIncrementStep(self): ...

    @AutoIncrementStep.setter
    def AutoIncrementStep(self): ...

    @property
    def Caption(self): ...

    @Caption.setter
    def Caption(self): ...

    def CheckNotAllowNull(self) -> None: ...

    def CheckUnique(self) -> None: ...

    @property
    def ColumnMapping(self): ...

    @ColumnMapping.setter
    def ColumnMapping(self): ...

    @property
    def ColumnName(self): ...

    @ColumnName.setter
    def ColumnName(self): ...

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    @property
    def DataType(self): ...

    @DataType.setter
    def DataType(self): ...

    @property
    def DateTimeMode(self): ...

    @DateTimeMode.setter
    def DateTimeMode(self): ...

    @property
    def DefaultValue(self): ...

    @DefaultValue.setter
    def DefaultValue(self): ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    def Dispose(self, _: bool) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Events(self): ...

    @Events.setter
    def Events(self): ...

    @property
    def Expression(self): ...

    @Expression.setter
    def Expression(self): ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetService(self, _: Type) -> object: ...

    def GetType(self) -> Type: ...

    @property
    def MaxLength(self): ...

    @MaxLength.setter
    def MaxLength(self): ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Namespace(self): ...

    @Namespace.setter
    def Namespace(self): ...

    def OnPropertyChanging(self,
            _: System.ComponentModel.PropertyChangedEventArgs,
            ) -> None: ...

    @property
    def Ordinal(self): ...

    @Ordinal.setter
    def Ordinal(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Prefix(self): ...

    @Prefix.setter
    def Prefix(self): ...

    def RaisePropertyChanging(self, _: str) -> None: ...

    @property
    def ReadOnly(self): ...

    @ReadOnly.setter
    def ReadOnly(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SetOrdinal(self, _: int) -> None: ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    @property
    def Unique(self): ...

    @Unique.setter
    def Unique(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_Disposed(self, _: Any) -> None: ...

    def get_AllowDBNull(self) -> bool: ...

    def get_AutoIncrement(self) -> bool: ...

    def get_AutoIncrementSeed(self) -> int: ...

    def get_AutoIncrementStep(self) -> int: ...

    def get_Caption(self) -> str: ...

    def get_ColumnMapping(self) -> MappingType: ...

    def get_ColumnName(self) -> str: ...

    def get_Container(self) -> System.ComponentModel.IContainer: ...

    def get_DataType(self) -> Type: ...

    def get_DateTimeMode(self) -> DataSetDateTime: ...

    def get_DefaultValue(self) -> object: ...

    def get_DesignMode(self) -> bool: ...

    def get_Events(self) -> System.ComponentModel.EventHandlerList: ...

    def get_Expression(self) -> str: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_MaxLength(self) -> int: ...

    def get_Namespace(self) -> str: ...

    def get_Ordinal(self) -> int: ...

    def get_Prefix(self) -> str: ...

    def get_ReadOnly(self) -> bool: ...

    def get_Site(self) -> System.ComponentModel.ISite: ...

    def get_Table(self) -> DataTable: ...

    def get_Unique(self) -> bool: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def set_AllowDBNull(self, _: bool) -> None: ...

    def set_AutoIncrement(self, _: bool) -> None: ...

    def set_AutoIncrementSeed(self, _: int) -> None: ...

    def set_AutoIncrementStep(self, _: int) -> None: ...

    def set_Caption(self, _: str) -> None: ...

    def set_ColumnMapping(self, _: MappingType) -> None: ...

    def set_ColumnName(self, _: str) -> None: ...

    def set_DataType(self, _: Type) -> None: ...

    def set_DateTimeMode(self, _: DataSetDateTime) -> None: ...

    def set_DefaultValue(self, _: object) -> None: ...

    def set_Expression(self, _: str) -> None: ...

    def set_MaxLength(self, _: int) -> None: ...

    def set_Namespace(self, _: str) -> None: ...

    def set_Prefix(self, _: str) -> None: ...

    def set_ReadOnly(self, _: bool) -> None: ...

    def set_Site(self, _: System.ComponentModel.ISite) -> None: ...

    def set_Unique(self, _: bool) -> None: ...


class IDataReader:

    def Close(self) -> None: ...

    @property
    def Depth(self): ...

    @Depth.setter
    def Depth(self): ...

    def Dispose(self) -> None: ...

    @property
    def FieldCount(self): ...

    @FieldCount.setter
    def FieldCount(self): ...

    def GetBoolean(self, _: int) -> bool: ...

    def GetByte(self, _: int) -> bytes: ...

    def GetBytes(self,
            _: int,
            __: int,
            ___: List[bytes],
            ____: int,
            _____: int,
            ) -> int: ...

    def GetChar(self, _: int) -> str: ...

    def GetChars(self, _: int, __: int, ___: List[str], ____: int, _____: int) -> int: ...

    def GetData(self, _: int) -> IDataReader: ...

    def GetDataTypeName(self, _: int) -> str: ...

    def GetDateTime(self, _: int) -> System.DateTime: ...

    def GetDecimal(self, _: int) -> float: ...

    def GetDouble(self, _: int) -> float: ...

    def GetFieldType(self, _: int) -> Type: ...

    def GetFloat(self, _: int) -> float: ...

    def GetGuid(self, _: int) -> System.Guid: ...

    def GetInt16(self, _: int) -> int: ...

    def GetInt32(self, _: int) -> int: ...

    def GetInt64(self, _: int) -> int: ...

    def GetName(self, _: int) -> str: ...

    def GetOrdinal(self, _: str) -> int: ...

    def GetSchemaTable(self) -> DataTable: ...

    def GetString(self, _: int) -> str: ...

    def GetValue(self, _: int) -> object: ...

    def GetValues(self, _: List[object]) -> int: ...

    @property
    def IsClosed(self): ...

    @IsClosed.setter
    def IsClosed(self): ...

    def IsDBNull(self, _: int) -> bool: ...

    def NextResult(self) -> bool: ...

    def Read(self) -> bool: ...

    @property
    def RecordsAffected(self): ...

    @RecordsAffected.setter
    def RecordsAffected(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Depth(self) -> int: ...

    def get_FieldCount(self) -> int: ...

    def get_IsClosed(self) -> bool: ...

    def get_Item(self, _: str) -> object: ...

    def get_RecordsAffected(self) -> int: ...


class LoadOption:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def OverwriteChanges(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def PreserveChanges(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Upsert(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class FillErrorEventHandler:

    def BeginInvoke(self,
            _: object,
            __: FillErrorEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: FillErrorEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class MissingSchemaAction:

    def Add(self, *args, **kwargs) -> Any: ...

    def AddWithKey(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Error(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def Ignore(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataRowBuilder:

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataRowChangeEventArgs:

    @property
    def Action(self): ...

    @Action.setter
    def Action(self): ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Row(self): ...

    @Row.setter
    def Row(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Action(self) -> DataRowAction: ...

    def get_Row(self) -> List: ...


class DataTableNewRowEventArgs:

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Row(self): ...

    @Row.setter
    def Row(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Row(self) -> List: ...


class DataTableNewRowEventHandler:

    def BeginInvoke(self,
            _: object,
            __: DataTableNewRowEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: DataTableNewRowEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class XmlReadMode:

    def Auto(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def DiffGram(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def Fragment(self, *args, **kwargs) -> Any: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IgnoreSchema(self, *args, **kwargs) -> Any: ...

    def InferSchema(self, *args, **kwargs) -> Any: ...

    def InferTypedSchema(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReadSchema(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class XmlWriteMode:

    def CompareTo(self, _: object) -> int: ...

    def DiffGram(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IgnoreSchema(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def WriteSchema(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataViewRowState:

    def Added(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def CurrentRows(self, *args, **kwargs) -> Any: ...

    def Deleted(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def ModifiedCurrent(self, *args, **kwargs) -> Any: ...

    def ModifiedOriginal(self, *args, **kwargs) -> Any: ...

    def OriginalRows(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Unchanged(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataColumnChangeEventHandler:

    def BeginInvoke(self, _: object, __: Any, ___: Any, ____: object) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: Any) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class DataRowChangeEventHandler:

    def BeginInvoke(self,
            _: object,
            __: DataRowChangeEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: DataRowChangeEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class DataView:

    def AddNew(self) -> DataRowView: ...

    @property
    def AllowDelete(self): ...

    @AllowDelete.setter
    def AllowDelete(self): ...

    @property
    def AllowEdit(self): ...

    @AllowEdit.setter
    def AllowEdit(self): ...

    @property
    def AllowNew(self): ...

    @AllowNew.setter
    def AllowNew(self): ...

    @property
    def ApplyDefaultSort(self): ...

    @ApplyDefaultSort.setter
    def ApplyDefaultSort(self): ...

    def BeginInit(self) -> None: ...

    def Close(self) -> None: ...

    def ColumnCollectionChanged(self,
            _: object,
            __: System.ComponentModel.CollectionChangeEventArgs,
            ) -> None: ...

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    @property
    def DataViewManager(self): ...

    @DataViewManager.setter
    def DataViewManager(self): ...

    def Delete(self, _: int) -> None: ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    def Dispose(self) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    def EndInit(self) -> None: ...

    def Equals(self, _: object) -> bool: ...

    @property
    def Events(self): ...

    @Events.setter
    def Events(self): ...

    def Finalize(self) -> None: ...

    def Find(self, _: object) -> int: ...

    def FindRows(self, _: object) -> List[DataRowView]: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetService(self, _: Type) -> object: ...

    def GetType(self) -> Type: ...

    def IndexListChanged(self,
            _: object,
            __: System.ComponentModel.ListChangedEventArgs,
            ) -> None: ...

    def Initialized(self, *args, **kwargs) -> Any: ...

    @property
    def IsInitialized(self): ...

    @IsInitialized.setter
    def IsInitialized(self): ...

    @property
    def IsOpen(self): ...

    @IsOpen.setter
    def IsOpen(self): ...

    def ListChanged(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def OnListChanged(self, _: System.ComponentModel.ListChangedEventArgs) -> None: ...

    def Open(self) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Reset(self) -> None: ...

    @property
    def RowFilter(self): ...

    @RowFilter.setter
    def RowFilter(self): ...

    @property
    def RowStateFilter(self): ...

    @RowStateFilter.setter
    def RowStateFilter(self): ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    @property
    def Sort(self): ...

    @Sort.setter
    def Sort(self): ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    def ToTable(self, _: str, __: bool, ___: List[str]) -> DataTable: ...

    def UpdateIndex(self, _: bool) -> None: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_Disposed(self, _: Any) -> None: ...

    def add_Initialized(self, _: Any) -> None: ...

    def add_ListChanged(self,
            _: System.ComponentModel.ListChangedEventHandler,
            ) -> None: ...

    def get_AllowDelete(self) -> bool: ...

    def get_AllowEdit(self) -> bool: ...

    def get_AllowNew(self) -> bool: ...

    def get_ApplyDefaultSort(self) -> bool: ...

    def get_Container(self) -> System.ComponentModel.IContainer: ...

    def get_Count(self) -> int: ...

    def get_DataViewManager(self) -> DataViewManager: ...

    def get_DesignMode(self) -> bool: ...

    def get_Events(self) -> System.ComponentModel.EventHandlerList: ...

    def get_IsInitialized(self) -> bool: ...

    def get_IsOpen(self) -> bool: ...

    def get_Item(self, _: int) -> DataRowView: ...

    def get_RowFilter(self) -> str: ...

    def get_RowStateFilter(self) -> DataViewRowState: ...

    def get_Site(self) -> System.ComponentModel.ISite: ...

    def get_Sort(self) -> str: ...

    def get_Table(self) -> DataTable: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def remove_Initialized(self, _: Any) -> None: ...

    def remove_ListChanged(self,
            _: System.ComponentModel.ListChangedEventHandler,
            ) -> None: ...

    def set_AllowDelete(self, _: bool) -> None: ...

    def set_AllowEdit(self, _: bool) -> None: ...

    def set_AllowNew(self, _: bool) -> None: ...

    def set_ApplyDefaultSort(self, _: bool) -> None: ...

    def set_RowFilter(self, _: str) -> None: ...

    def set_RowStateFilter(self, _: DataViewRowState) -> None: ...

    def set_Site(self, _: System.ComponentModel.ISite) -> None: ...

    def set_Sort(self, _: str) -> None: ...

    def set_Table(self, _: DataTable) -> None: ...


class DataColumnCollection:

    def Add(self, _: str, __: Type, ___: str) -> List: ...

    def AddRange(self, _: List[List]) -> None: ...

    def CanRemove(self, _: List) -> bool: ...

    def Clear(self) -> None: ...

    def CollectionChanged(self, *args, **kwargs) -> Any: ...

    def Contains(self, _: str) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: str) -> int: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: str) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: str) -> List: ...

    def get_List(self) -> List: ...

    def get_SyncRoot(self) -> object: ...

    def remove_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...


class DataRowCollection:

    def Add(self, _: List) -> None: ...

    def Clear(self) -> None: ...

    def Contains(self, _: object) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Find(self, _: object) -> List: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: List) -> int: ...

    def InsertAt(self, _: List, __: int) -> None: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: List) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: int) -> List: ...

    def get_List(self) -> List: ...

    def get_SyncRoot(self) -> object: ...


class DataRelationCollection:

    def Add(self, _: str, __: List, ___: List, ____: bool) -> DataRelation: ...

    def AddCore(self, _: DataRelation) -> None: ...

    def AddRange(self, _: List[DataRelation]) -> None: ...

    def CanRemove(self, _: DataRelation) -> bool: ...

    def Clear(self) -> None: ...

    def CollectionChanged(self, *args, **kwargs) -> Any: ...

    def Contains(self, _: str) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetDataSet(self) -> DataSet: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: str) -> int: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def OnCollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventArgs,
            ) -> None: ...

    def OnCollectionChanging(self,
            _: System.ComponentModel.CollectionChangeEventArgs,
            ) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: str) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    def RemoveCore(self, _: DataRelation) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: str) -> DataRelation: ...

    def get_List(self) -> List: ...

    def get_SyncRoot(self) -> object: ...

    def remove_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...


class PropertyCollection:

    def Add(self, _: object, __: object) -> None: ...

    def Clear(self) -> None: ...

    def Clone(self) -> object: ...

    def Contains(self, _: object) -> bool: ...

    def ContainsKey(self, _: object) -> bool: ...

    def ContainsValue(self, _: object) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    @property
    def EqualityComparer(self): ...

    @EqualityComparer.setter
    def EqualityComparer(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IDictionaryEnumerator: ...

    def GetHash(self, _: object) -> int: ...

    def GetHashCode(self) -> int: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    @property
    def IsFixedSize(self): ...

    @IsFixedSize.setter
    def IsFixedSize(self): ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    def KeyEquals(self, _: object, __: object) -> bool: ...

    @property
    def Keys(self): ...

    @Keys.setter
    def Keys(self): ...

    def MemberwiseClone(self) -> object: ...

    def OnDeserialization(self, _: object) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: object) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def Synchronized(self,
            _: System.Collections.Hashtable,
            ) -> System.Collections.Hashtable: ...

    def ToString(self) -> str: ...

    @property
    def Values(self): ...

    @Values.setter
    def Values(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    @property
    def comparer(self): ...

    @comparer.setter
    def comparer(self): ...

    def get_Count(self) -> int: ...

    def get_EqualityComparer(self) -> System.Collections.IEqualityComparer: ...

    def get_IsFixedSize(self) -> bool: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: object) -> object: ...

    def get_Keys(self) -> System.Collections.ICollection: ...

    def get_SyncRoot(self) -> object: ...

    def get_Values(self) -> System.Collections.ICollection: ...

    def get_comparer(self) -> System.Collections.IComparer: ...

    def get_hcp(self) -> System.Collections.IHashCodeProvider: ...

    @property
    def hcp(self): ...

    @hcp.setter
    def hcp(self): ...

    def set_Item(self, _: object, __: object) -> None: ...

    def set_comparer(self, _: System.Collections.IComparer) -> None: ...

    def set_hcp(self, _: System.Collections.IHashCodeProvider) -> None: ...


class SerializationFormat:

    def Binary(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Xml(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataTableClearEventArgs:

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    @property
    def TableName(self): ...

    @TableName.setter
    def TableName(self): ...

    @property
    def TableNamespace(self): ...

    @TableNamespace.setter
    def TableNamespace(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Table(self) -> DataTable: ...

    def get_TableName(self) -> str: ...

    def get_TableNamespace(self) -> str: ...


class DataTableClearEventHandler:

    def BeginInvoke(self,
            _: object,
            __: DataTableClearEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: DataTableClearEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class ConstraintCollection:

    def Add(self, _: str, __: List[List], ___: bool) -> Constraint: ...

    def AddRange(self, _: List[Constraint]) -> None: ...

    def CanRemove(self, _: Constraint) -> bool: ...

    def Clear(self) -> None: ...

    def CollectionChanged(self, *args, **kwargs) -> Any: ...

    def Contains(self, _: str) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: str) -> int: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: str) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: str) -> Constraint: ...

    def get_List(self) -> List: ...

    def get_SyncRoot(self) -> object: ...

    def remove_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...


class DataRowVersion:

    def CompareTo(self, _: object) -> int: ...

    def Current(self, *args, **kwargs) -> Any: ...

    def Default(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Original(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def Proposed(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataRelation:

    def CheckStateForProperty(self) -> None: ...

    @property
    def ChildColumns(self): ...

    @ChildColumns.setter
    def ChildColumns(self): ...

    @property
    def ChildKeyConstraint(self): ...

    @ChildKeyConstraint.setter
    def ChildKeyConstraint(self): ...

    @property
    def ChildTable(self): ...

    @ChildTable.setter
    def ChildTable(self): ...

    @property
    def DataSet(self): ...

    @DataSet.setter
    def DataSet(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Nested(self): ...

    @Nested.setter
    def Nested(self): ...

    def OnPropertyChanging(self,
            _: System.ComponentModel.PropertyChangedEventArgs,
            ) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def ParentColumns(self): ...

    @ParentColumns.setter
    def ParentColumns(self): ...

    @property
    def ParentKeyConstraint(self): ...

    @ParentKeyConstraint.setter
    def ParentKeyConstraint(self): ...

    @property
    def ParentTable(self): ...

    @ParentTable.setter
    def ParentTable(self): ...

    def RaisePropertyChanging(self, _: str) -> None: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def RelationName(self): ...

    @RelationName.setter
    def RelationName(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_ChildColumns(self) -> List[List]: ...

    def get_ChildKeyConstraint(self) -> ForeignKeyConstraint: ...

    def get_ChildTable(self) -> DataTable: ...

    def get_DataSet(self) -> DataSet: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_Nested(self) -> bool: ...

    def get_ParentColumns(self) -> List[List]: ...

    def get_ParentKeyConstraint(self) -> UniqueConstraint: ...

    def get_ParentTable(self) -> DataTable: ...

    def get_RelationName(self) -> str: ...

    def set_Nested(self, _: bool) -> None: ...

    def set_RelationName(self, _: str) -> None: ...


class MappingType:

    def Attribute(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Element(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def Hidden(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SimpleContent(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class DataSetDateTime:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def Local(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def Unspecified(self, *args, **kwargs) -> Any: ...

    def UnspecifiedLocal(self, *args, **kwargs) -> Any: ...

    def Utc(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class FillErrorEventArgs:

    @property
    def Continue(self): ...

    @Continue.setter
    def Continue(self): ...

    @property
    def DataTable(self): ...

    @DataTable.setter
    def DataTable(self): ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Errors(self): ...

    @Errors.setter
    def Errors(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToString(self) -> str: ...

    @property
    def Values(self): ...

    @Values.setter
    def Values(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Continue(self) -> bool: ...

    def get_DataTable(self) -> DataTable: ...

    def get_Errors(self) -> Exception: ...

    def get_Values(self) -> List[object]: ...

    def set_Continue(self, _: bool) -> None: ...

    def set_Errors(self, _: Exception) -> None: ...


class DataRowAction:

    def Add(self, *args, **kwargs) -> Any: ...

    def Change(self, *args, **kwargs) -> Any: ...

    def ChangeCurrentAndOriginal(self, *args, **kwargs) -> Any: ...

    def ChangeOriginal(self, *args, **kwargs) -> Any: ...

    def Commit(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Delete(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Nothing(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Rollback(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class MergeFailedEventHandler:

    def BeginInvoke(self,
            _: object,
            __: MergeFailedEventArgs,
            ___: Any,
            ____: object,
            ) -> Any: ...

    def Clone(self) -> object: ...

    def Combine(self, _: Any, __: Any) -> Any: ...

    def CombineImpl(self, _: Any) -> Any: ...

    def CreateDelegate(self,
            _: Type,
            __: object,
            ___: str,
            ____: bool,
            _____: bool,
            ) -> Any: ...

    def DynamicInvoke(self, _: List[object]) -> object: ...

    def DynamicInvokeImpl(self, _: List[object]) -> object: ...

    def EndInvoke(self, _: Any) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetInvocationList(self) -> List[Any]: ...

    def GetMethodImpl(self) -> System.Reflection.MethodInfo: ...

    def GetObjectData(self,
            _: System.Runtime.Serialization.SerializationInfo,
            __: System.Runtime.Serialization.StreamingContext,
            ) -> None: ...

    def GetType(self) -> Type: ...

    def Invoke(self, _: object, __: MergeFailedEventArgs) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Method(self): ...

    @Method.setter
    def Method(self): ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: Any, __: Any) -> Any: ...

    def RemoveAll(self, _: Any, __: Any) -> Any: ...

    def RemoveImpl(self, _: Any) -> Any: ...

    @property
    def Target(self): ...

    @Target.setter
    def Target(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Method(self) -> System.Reflection.MethodInfo: ...

    def get_Target(self) -> object: ...

    def op_Equality(self, _: Any, __: Any) -> bool: ...

    def op_Inequality(self, _: Any, __: Any) -> bool: ...


class DataViewManager:

    @property
    def Container(self): ...

    @Container.setter
    def Container(self): ...

    def CreateDataView(self, _: DataTable) -> DataView: ...

    @property
    def DataSet(self): ...

    @DataSet.setter
    def DataSet(self): ...

    @property
    def DataViewSettingCollectionString(self): ...

    @DataViewSettingCollectionString.setter
    def DataViewSettingCollectionString(self): ...

    @property
    def DataViewSettings(self): ...

    @DataViewSettings.setter
    def DataViewSettings(self): ...

    @property
    def DesignMode(self): ...

    @DesignMode.setter
    def DesignMode(self): ...

    def Dispose(self, _: bool) -> None: ...

    def Disposed(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def Events(self): ...

    @Events.setter
    def Events(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetService(self, _: Type) -> object: ...

    def GetType(self) -> Type: ...

    def ListChanged(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def OnListChanged(self, _: System.ComponentModel.ListChangedEventArgs) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RelationCollectionChanged(self,
            _: object,
            __: System.ComponentModel.CollectionChangeEventArgs,
            ) -> None: ...

    @property
    def Site(self): ...

    @Site.setter
    def Site(self): ...

    def TableCollectionChanged(self,
            _: object,
            __: System.ComponentModel.CollectionChangeEventArgs,
            ) -> None: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_Disposed(self, _: Any) -> None: ...

    def add_ListChanged(self,
            _: System.ComponentModel.ListChangedEventHandler,
            ) -> None: ...

    def get_Container(self) -> System.ComponentModel.IContainer: ...

    def get_DataSet(self) -> DataSet: ...

    def get_DataViewSettingCollectionString(self) -> str: ...

    def get_DataViewSettings(self) -> DataViewSettingCollection: ...

    def get_DesignMode(self) -> bool: ...

    def get_Events(self) -> System.ComponentModel.EventHandlerList: ...

    def get_Site(self) -> System.ComponentModel.ISite: ...

    def remove_Disposed(self, _: Any) -> None: ...

    def remove_ListChanged(self,
            _: System.ComponentModel.ListChangedEventHandler,
            ) -> None: ...

    def set_DataSet(self, _: DataSet) -> None: ...

    def set_DataViewSettingCollectionString(self, _: str) -> None: ...

    def set_Site(self, _: System.ComponentModel.ISite) -> None: ...


class DataTableCollection:

    def Add(self, _: str, __: str) -> DataTable: ...

    def AddRange(self, _: List[DataTable]) -> None: ...

    def CanRemove(self, _: DataTable) -> bool: ...

    def Clear(self) -> None: ...

    def CollectionChanged(self, *args, **kwargs) -> Any: ...

    def CollectionChanging(self, *args, **kwargs) -> Any: ...

    def Contains(self, _: str, __: str) -> bool: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IndexOf(self, _: str, __: str) -> int: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    @property
    def List(self): ...

    @List.setter
    def List(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Remove(self, _: str, __: str) -> None: ...

    def RemoveAt(self, _: int) -> None: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...

    def add_CollectionChanging(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: str, __: str) -> DataTable: ...

    def get_List(self) -> List: ...

    def get_SyncRoot(self) -> object: ...

    def remove_CollectionChanged(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...

    def remove_CollectionChanging(self,
            _: System.ComponentModel.CollectionChangeEventHandler,
            ) -> None: ...


class DataRowView:

    def BeginEdit(self) -> None: ...

    def CancelEdit(self) -> None: ...

    def CreateChildView(self, _: str, __: bool) -> DataView: ...

    @property
    def DataView(self): ...

    @DataView.setter
    def DataView(self): ...

    def Delete(self) -> None: ...

    def EndEdit(self) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def IsEdit(self): ...

    @IsEdit.setter
    def IsEdit(self): ...

    @property
    def IsNew(self): ...

    @IsNew.setter
    def IsNew(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def PropertyChanged(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Row(self): ...

    @Row.setter
    def Row(self): ...

    @property
    def RowVersion(self): ...

    @RowVersion.setter
    def RowVersion(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def add_PropertyChanged(self,
            _: System.ComponentModel.PropertyChangedEventHandler,
            ) -> None: ...

    def get_DataView(self) -> DataView: ...

    def get_IsEdit(self) -> bool: ...

    def get_IsNew(self) -> bool: ...

    def get_Item(self, _: str) -> object: ...

    def get_Row(self) -> List: ...

    def get_RowVersion(self) -> DataRowVersion: ...

    def remove_PropertyChanged(self,
            _: System.ComponentModel.PropertyChangedEventHandler,
            ) -> None: ...

    def set_Item(self, _: str, __: object) -> None: ...


class MergeFailedEventArgs:

    @property
    def Conflict(self): ...

    @Conflict.setter
    def Conflict(self): ...

    def Empty(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Conflict(self) -> str: ...

    def get_Table(self) -> DataTable: ...


class DataViewSettingCollection:

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_Item(self, _: str) -> DataViewSetting: ...

    def get_SyncRoot(self) -> object: ...

    def set_Item(self, _: int, __: DataViewSetting) -> None: ...


class DataViewSetting:

    @property
    def ApplyDefaultSort(self): ...

    @ApplyDefaultSort.setter
    def ApplyDefaultSort(self): ...

    @property
    def DataViewManager(self): ...

    @DataViewManager.setter
    def DataViewManager(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def RowFilter(self): ...

    @RowFilter.setter
    def RowFilter(self): ...

    @property
    def RowStateFilter(self): ...

    @RowStateFilter.setter
    def RowStateFilter(self): ...

    @property
    def Sort(self): ...

    @Sort.setter
    def Sort(self): ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_ApplyDefaultSort(self) -> bool: ...

    def get_DataViewManager(self) -> DataViewManager: ...

    def get_RowFilter(self) -> str: ...

    def get_RowStateFilter(self) -> DataViewRowState: ...

    def get_Sort(self) -> str: ...

    def get_Table(self) -> DataTable: ...

    def set_ApplyDefaultSort(self, _: bool) -> None: ...

    def set_RowFilter(self, _: str) -> None: ...

    def set_RowStateFilter(self, _: DataViewRowState) -> None: ...

    def set_Sort(self, _: str) -> None: ...


class Constraint:

    def CheckStateForProperty(self) -> None: ...

    @property
    def ConstraintName(self): ...

    @ConstraintName.setter
    def ConstraintName(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SetDataSet(self, _: DataSet) -> None: ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    @property
    def _DataSet(self): ...

    @_DataSet.setter
    def _DataSet(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_ConstraintName(self) -> str: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_Table(self) -> DataTable: ...

    def get__DataSet(self) -> DataSet: ...

    def set_ConstraintName(self, _: str) -> None: ...


class ForeignKeyConstraint:

    @property
    def AcceptRejectRule(self): ...

    @AcceptRejectRule.setter
    def AcceptRejectRule(self): ...

    def CheckStateForProperty(self) -> None: ...

    @property
    def Columns(self): ...

    @Columns.setter
    def Columns(self): ...

    @property
    def ConstraintName(self): ...

    @ConstraintName.setter
    def ConstraintName(self): ...

    @property
    def DeleteRule(self): ...

    @DeleteRule.setter
    def DeleteRule(self): ...

    def Equals(self, _: object) -> bool: ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def RelatedColumns(self): ...

    @RelatedColumns.setter
    def RelatedColumns(self): ...

    @property
    def RelatedTable(self): ...

    @RelatedTable.setter
    def RelatedTable(self): ...

    def SetDataSet(self, _: DataSet) -> None: ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    @property
    def UpdateRule(self): ...

    @UpdateRule.setter
    def UpdateRule(self): ...

    @property
    def _DataSet(self): ...

    @_DataSet.setter
    def _DataSet(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_AcceptRejectRule(self) -> AcceptRejectRule: ...

    def get_Columns(self) -> List[List]: ...

    def get_ConstraintName(self) -> str: ...

    def get_DeleteRule(self) -> Rule: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_RelatedColumns(self) -> List[List]: ...

    def get_RelatedTable(self) -> DataTable: ...

    def get_Table(self) -> DataTable: ...

    def get_UpdateRule(self) -> Rule: ...

    def get__DataSet(self) -> DataSet: ...

    def set_AcceptRejectRule(self, _: AcceptRejectRule) -> None: ...

    def set_ConstraintName(self, _: str) -> None: ...

    def set_DeleteRule(self, _: Rule) -> None: ...

    def set_UpdateRule(self, _: Rule) -> None: ...


class UniqueConstraint:

    def CheckStateForProperty(self) -> None: ...

    @property
    def Columns(self): ...

    @Columns.setter
    def Columns(self): ...

    @property
    def ConstraintName(self): ...

    @ConstraintName.setter
    def ConstraintName(self): ...

    def Equals(self, _: object) -> bool: ...

    @property
    def ExtendedProperties(self): ...

    @ExtendedProperties.setter
    def ExtendedProperties(self): ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    @property
    def IsPrimaryKey(self): ...

    @IsPrimaryKey.setter
    def IsPrimaryKey(self): ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SetDataSet(self, _: DataSet) -> None: ...

    @property
    def Table(self): ...

    @Table.setter
    def Table(self): ...

    def ToString(self) -> str: ...

    @property
    def _DataSet(self): ...

    @_DataSet.setter
    def _DataSet(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Columns(self) -> List[List]: ...

    def get_ConstraintName(self) -> str: ...

    def get_ExtendedProperties(self) -> PropertyCollection: ...

    def get_IsPrimaryKey(self) -> bool: ...

    def get_Table(self) -> DataTable: ...

    def get__DataSet(self) -> DataSet: ...

    def set_ConstraintName(self, _: str) -> None: ...


class Rule:

    def Cascade(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SetDefault(self, *args, **kwargs) -> Any: ...

    def SetNull(self, *args, **kwargs) -> Any: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class SchemaSerializationMode:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def ExcludeSchema(self, *args, **kwargs) -> Any: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IncludeSchema(self, *args, **kwargs) -> Any: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.IO
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class PermissionSet:

    def AddPermission(self,
            _: System.Security.IPermission,
            ) -> System.Security.IPermission: ...

    def AddPermissionImpl(self,
            _: System.Security.IPermission,
            ) -> System.Security.IPermission: ...

    def Assert(self) -> None: ...

    def ContainsNonCodeAccessPermissions(self) -> bool: ...

    def ConvertPermissionSet(self, _: str, __: List[bytes], ___: str) -> List[bytes]: ...

    def Copy(self) -> System.Security.PermissionSet: ...

    def CopyTo(self, _: List, __: int) -> None: ...

    @property
    def Count(self): ...

    @Count.setter
    def Count(self): ...

    def Demand(self) -> None: ...

    def Deny(self) -> None: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def FromXml(self, _: System.Security.SecurityElement) -> None: ...

    def GetEnumerator(self) -> System.Collections.IEnumerator: ...

    def GetEnumeratorImpl(self) -> System.Collections.IEnumerator: ...

    def GetHashCode(self) -> int: ...

    def GetPermission(self, _: Type) -> System.Security.IPermission: ...

    def GetPermissionImpl(self, _: Type) -> System.Security.IPermission: ...

    def GetType(self) -> Type: ...

    def Intersect(self,
            _: System.Security.PermissionSet,
            ) -> System.Security.PermissionSet: ...

    def IsEmpty(self) -> bool: ...

    @property
    def IsReadOnly(self): ...

    @IsReadOnly.setter
    def IsReadOnly(self): ...

    def IsSubsetOf(self, _: System.Security.PermissionSet) -> bool: ...

    @property
    def IsSynchronized(self): ...

    @IsSynchronized.setter
    def IsSynchronized(self): ...

    def IsUnrestricted(self) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def PermitOnly(self) -> None: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def RemovePermission(self, _: Type) -> System.Security.IPermission: ...

    def RemovePermissionImpl(self, _: Type) -> System.Security.IPermission: ...

    def RevertAssert(self) -> None: ...

    def SetPermission(self,
            _: System.Security.IPermission,
            ) -> System.Security.IPermission: ...

    def SetPermissionImpl(self,
            _: System.Security.IPermission,
            ) -> System.Security.IPermission: ...

    @property
    def SyncRoot(self): ...

    @SyncRoot.setter
    def SyncRoot(self): ...

    def ToString(self) -> str: ...

    def ToXml(self) -> System.Security.SecurityElement: ...

    def Union(self, _: System.Security.PermissionSet) -> System.Security.PermissionSet: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Count(self) -> int: ...

    def get_IsReadOnly(self) -> bool: ...

    def get_IsSynchronized(self) -> bool: ...

    def get_SyncRoot(self) -> object: ...


class SecurityRuleSet:

    def CompareTo(self, _: object) -> int: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def Level1(self, *args, **kwargs) -> Any: ...

    def Level2(self, *args, **kwargs) -> Any: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class IPermission:

    def Copy(self) -> System.Security.IPermission: ...

    def Demand(self) -> None: ...

    def FromXml(self, _: System.Security.SecurityElement) -> None: ...

    def Intersect(self, _: System.Security.IPermission) -> System.Security.IPermission: ...

    def IsSubsetOf(self, _: System.Security.IPermission) -> bool: ...

    def ToXml(self) -> System.Security.SecurityElement: ...

    def Union(self, _: System.Security.IPermission) -> System.Security.IPermission: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class SecurityElement:

    def AddAttribute(self, _: str, __: str) -> None: ...

    def AddChild(self, _: System.Security.SecurityElement) -> None: ...

    def Attribute(self, _: str) -> str: ...

    @property
    def Attributes(self): ...

    @Attributes.setter
    def Attributes(self): ...

    @property
    def Children(self): ...

    @Children.setter
    def Children(self): ...

    def Copy(self) -> System.Security.SecurityElement: ...

    def Equal(self, _: System.Security.SecurityElement) -> bool: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Escape(self, _: str) -> str: ...

    def Finalize(self) -> None: ...

    def FromString(self, _: str) -> System.Security.SecurityElement: ...

    def GetHashCode(self) -> int: ...

    def GetType(self) -> Type: ...

    def IsValidAttributeName(self, _: str) -> bool: ...

    def IsValidAttributeValue(self, _: str) -> bool: ...

    def IsValidTag(self, _: str) -> bool: ...

    def IsValidText(self, _: str) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def SearchForChildByTag(self, _: str) -> System.Security.SecurityElement: ...

    def SearchForTextOfTag(self, _: str) -> str: ...

    @property
    def Tag(self): ...

    @Tag.setter
    def Tag(self): ...

    @property
    def Text(self): ...

    @Text.setter
    def Text(self): ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Attributes(self) -> System.Collections.Hashtable: ...

    def get_Children(self) -> List: ...

    def get_Tag(self) -> str: ...

    def get_Text(self) -> str: ...

    def set_Attributes(self, _: System.Collections.Hashtable) -> None: ...

    def set_Children(self, _: List) -> None: ...

    def set_Tag(self, _: str) -> None: ...

    def set_Text(self, _: str) -> None: ...



#!/usr/bin/env python3
#
#  __main__.py
#
#  Copyright © 2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
#  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
#  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
#  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
#  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
#  OR OTHER DEALINGS IN THE SOFTWARE.
#

# 3rd party
import clr  # type: ignore
from domdf_python_tools.paths import PathPlus

# this package
from dotnet_stub_builder.makers import make_module, make_package

clr.AddReference("System")
clr.AddReference("System.Collections")
clr.AddReference("System.Configuration")
clr.AddReference("System.Data")
clr.AddReference("System.Globalization")
clr.AddReference("System.IO")
clr.AddReference("System.Reflection")
clr.AddReference("System.Runtime")
clr.AddReference("System.Runtime.InteropServices")
clr.AddReference("System.Runtime.Remoting")
clr.AddReference("System.Runtime.Serialization")
clr.AddReference("System.Security")
clr.AddReference("System.Threading")
clr.AddReference("System.Threading.Tasks")
clr.AddReference("System.Xml")
clr.AddReference("System.Xml.Serialization")

# 3rd party
import System  # type: ignore
import System.Collections  # type: ignore
import System.Configuration  # type: ignore
import System.Configuration.Assemblies  # type: ignore
import System.Data  # type: ignore
import System.Globalization  # type: ignore
import System.IO  # type: ignore
import System.Reflection  # type: ignore
import System.Runtime  # type: ignore
import System.Runtime.CompilerServices  # type: ignore
import System.Runtime.InteropServices  # type: ignore
import System.Runtime.Remoting  # type: ignore
import System.Runtime.Serialization  # type: ignore
import System.Security  # type: ignore
import System.Security.AccessControl  # type: ignore
import System.Security.Cryptography  # type: ignore
import System.Security.Cryptography.X509Certificates  # type: ignore
import System.Security.Policy  # type: ignore
import System.Threading  # type: ignore
import System.Threading.Tasks  # type: ignore
import System.Xml  # type: ignore
import System.Xml.Schema  # type: ignore
import System.Xml.Serialization  # type: ignore

__all__ = ["build_stubs"]


def build_stubs():
	# System
	system_stubs_dir = PathPlus("System-stubs")
	system_stubs_dir.maybe_make()

	make_package(
			"System",
			System,
			[
					"TypeCode",
					"Predicate",
					"TimeSpan",
					"ModuleHandle",
					"Delegate",
					"IAsyncResult",
					"MulticastDelegate",
					"EventHandler",
					"IFormatProvider",
					"AsyncCallback",
					"EventArgs",
					"DateTime",
					"Guid",
					"Converter",
					"RuntimeMethodHandle",
					"RuntimeTypeHandle",
					"DateTimeKind",
					"RuntimeFieldHandle",
					"Version",
					"ResolveEventArgs",
					"Action",
					"Object",
					"Func",
					"Attribute",
					"DayOfWeek",
					"DateTimeOffset",
					]
			)

	# System.Data
	make_module(
			"System.Data",
			System.Data,
			[
					"InternalDataCollectionBase",
					"AcceptRejectRule",
					"DataTable",
					"DataTableReader",
					"DataRowState",
					"DataRow",
					"DataSet",
					"DataColumn",
					"IDataReader",
					"LoadOption",
					"FillErrorEventHandler",
					"MissingSchemaAction",
					"DataRowBuilder",
					"DataRowChangeEventArgs",
					"DataTableNewRowEventArgs",
					"DataTableNewRowEventHandler",
					"XmlReadMode",
					"XmlWriteMode",
					"DataViewRowState",
					"DataColumnChangeEventHandler",
					"DataRowChangeEventHandler",
					"DataView",
					"DataColumnCollection",
					"DataRowCollection",
					"DataRelationCollection",
					"PropertyCollection",
					"SerializationFormat",
					"DataTableClearEventArgs",
					"DataTableClearEventHandler",
					"ConstraintCollection",
					"DataRowVersion",
					"DataRelation",
					"MappingType",
					"DataSetDateTime",
					"FillErrorEventArgs",
					"DataRowAction",
					"MergeFailedEventHandler",
					"DataViewManager",
					"DataTableCollection",
					"DataRowView",
					"MergeFailedEventArgs",
					"DataViewSettingCollection",
					"DataViewSetting",
					"Constraint",
					"ForeignKeyConstraint",
					"UniqueConstraint",
					"Rule",
					"SchemaSerializationMode",
					]
			)

	# System.Xml
	make_package(
			"System.Xml",
			System.Xml,
			[
					"XmlReader",
					"XmlWriter",
					"XmlReaderSettings",
					"XmlNodeType",
					"IXmlNamespaceResolver",
					"XmlNameTable",
					"XmlWriterSettings",
					"XmlResolver",
					"XmlQualifiedName",
					"XmlAttribute",
					"XmlTokenizedType",
					"XmlOutputMethod",
					"XmlNode",
					"XmlNodeList",
					"XmlNamespaceManager",
					"XmlAttributeCollection",
					"XmlElement",
					"XmlNamespaceScope",
					"XmlDocument",
					"XmlEntityReference",
					"XmlSignificantWhitespace",
					"XmlDocumentFragment",
					"XmlText",
					"XmlWhitespace",
					"XmlDeclaration",
					"ReadState",
					"XmlSpace",
					"NewLineHandling",
					"NamespaceHandling",
					"XmlCDataSection",
					"XmlComment",
					"XmlDocumentType",
					"XmlProcessingInstruction",
					"XmlNodeChangedEventHandler",
					"ValidationType",
					"ConformanceLevel",
					"DtdProcessing",
					"WriteState",
					"XmlNamedNodeMap",
					"XmlImplementation",
					"XmlNodeChangedEventArgs",
					]
			)

	# System.Xml.Schema
	make_module(
			"System.Xml.Schema",
			System.Xml.Schema,
			[
					"XmlSchema",
					"XmlTypeCode",
					"XmlSchemaSimpleType",
					"XmlSchemaSet",
					"XmlSchemaForm",
					"XmlSchemaType",
					"XmlSchemaObject",
					"XmlSchemaContentModel",
					"XmlSchemaDatatype",
					"XmlSchemaObjectTable",
					"XmlSchemaAnyAttribute",
					"XmlSchemaComplexType",
					"XmlSchemaParticle",
					"XmlSchemaCompilationSettings",
					"XmlSchemaObjectCollection",
					"XmlSchemaDerivationMethod",
					"ValidationEventHandler",
					"XmlSchemaAnnotation",
					"ValidationEventArgs",
					"XmlSchemaSimpleTypeContent",
					"XmlSchemaContent",
					"XmlSchemaContentType",
					"XmlSchemaException",
					"XmlSeverityType",
					"XmlSchemaContentProcessing",
					"XmlSchemaDatatypeVariety",
					"IXmlSchemaInfo",
					"XmlSchemaValidationFlags",
					"XmlSchemaValidity",
					"XmlSchemaElement",
					"XmlSchemaAttribute",
					"XmlSchemaUse",
					]
			)

	# System.Xml.Serialization
	make_module(
			"System.Xml.Serialization",
			System.Xml.Serialization,
			["XmlSerializerNamespaces"],
			)

	# System.Runtime
	make_package("System.Runtime", System.Runtime, [])

	# System.Runtime.Serialization
	make_module(
			"System.Runtime.Serialization",
			System.Runtime.Serialization,
			[
					"StreamingContextStates",
					"SerializationEntry",
					"SerializationInfo",
					"StreamingContext",
					"SerializationInfoEnumerator",
					"SafeSerializationEventArgs",
					]
			)

	# System.Runtime.CompilerServices
	make_module(
			"System.Runtime.CompilerServices",
			System.Runtime.CompilerServices, ["ConfiguredTaskAwaitable", "TaskAwaiter", "YieldAwaitable"]
			)

	# System.Runtime.Remoting
	make_module("System.Runtime.Remoting", System.Runtime.Remoting, [
			"ObjRef",
			])

	# System.Runtime.InteropServices
	make_module("System.Runtime.InteropServices", System.Runtime.InteropServices, [
			"StructLayoutAttribute",
			])

	# System.Collections
	make_module(
			"System.Collections",
			System.Collections,
			[
					"IEnumerator",
					"IDictionary",
					"ArrayList",
					"IDictionaryEnumerator",
					"IEqualityComparer",
					"ICollection",
					"IHashCodeProvider",
					"IComparer",
					"Hashtable",
					"DictionaryEntry",
					"IList",
					]
			)

	# System.Globalization
	make_module(
			"System.Globalization",
			System.Globalization,
			[
					"CultureInfo",
					"DateTimeFormatInfo",
					"NumberFormatInfo",
					"DateTimeStyles",
					"DigitShapes",
					"TimeSpanStyles",
					]
			)

	# System.ComponentModel
	make_module(
			"System.ComponentModel",
			System.ComponentModel,
			[
					"ITypeDescriptorContext",
					"PropertyDescriptor",
					"AttributeCollection",
					"PropertyDescriptorCollection",
					"TypeConverter",
					"DesignerSerializationVisibility",
					"MarshalByValueComponent",
					"PropertyChangedEventArgs",
					"PropertyChangedEventHandler",
					"CollectionChangeEventArgs",
					"CollectionChangeEventHandler",
					"ListChangedEventArgs",
					"ListChangedEventHandler",
					"IContainer",
					"EventHandlerList",
					"ISite",
					"CollectionChangeAction",
					"IComponent",
					"ComponentCollection",
					"ListChangedType",
					]
			)

	# System.IO
	make_module("System.IO", System.IO, [
			"Stream",
			"TextReader",
			"SeekOrigin",
			"FileStream",
			"TextWriter",
			])

	# System.Threading
	make_package(
			"System.Threading",
			System.Threading,
			["CancellationToken", "WaitHandle", "CancellationTokenRegistration"],
			)

	# System.Threading.Tasks
	make_module(
			"System.Threading.Tasks",
			System.Threading.Tasks,
			[
					"Task",
					"TaskScheduler",
					"TaskFactory",
					"TaskCreationOptions",
					"TaskStatus",
					"UnobservedTaskExceptionEventArgs",
					"TaskContinuationOptions",
					],
			)

	# System.Reflection
	make_module(
			"System.Reflection",
			System.Reflection,
			[
					"MemberInfo",
					"MethodBase",
					"MethodInfo",
					"Module",
					"TypeInfo",
					"TypeFilter",
					"Assembly",
					"EventAttributes",
					"AssemblyContentType",
					"ExceptionHandlingClauseOptions",
					"PropertyAttributes",
					"PortableExecutableKinds",
					"ImageFileMachine",
					"CustomAttributeNamedArgument",
					"ConstructorInfo",
					"CustomAttributeTypedArgument",
					"ExceptionHandlingClause",
					"LocalVariableInfo",
					"MethodAttributes",
					"CallingConventions",
					"CustomAttributeData",
					"MethodBody",
					"ParameterInfo",
					"MethodImplAttributes",
					"BindingFlags",
					"Binder",
					"FieldAttributes",
					"ModuleResolveEventHandler",
					"MemberTypes",
					"MemberFilter",
					"TypeAttributes",
					"EventInfo",
					"InterfaceMapping",
					"ICustomAttributeProvider",
					"ParameterModifier",
					"PropertyInfo",
					"ParameterAttributes",
					"FieldInfo",
					"ManifestResourceInfo",
					"AssemblyName",
					"AssemblyNameFlags",
					"StrongNameKeyPair",
					]
			)

	# System.Security
	make_package(
			"System.Security",
			System.Security,
			["PermissionSet", "SecurityRuleSet", "IPermission", "SecurityElement"],
			)

	# System.Security.Policy
	make_module("System.Security.Policy", System.Security.Policy, ["Evidence"])

	# System.Security.Cryptography
	make_package("System.Security.Cryptography", System.Security.Cryptography, ["HashAlgorithmName"])

	# System.Security.AccessControl
	make_package("System.Security.AccessControl", System.Security.AccessControl, ["FileSecurity"])

	# System.Security.Cryptography.X509Certificates
	make_package(
			"System.Security.Cryptography.X509Certificates",
			System.Security.Cryptography.X509Certificates,
			["X509Certificate", "X509ContentType", "X509KeyStorageFlags"],
			)

	# System.Configuration
	make_package("System.Configuration", System.Configuration, [])

	# System.Configuration.Assemblies
	make_module(
			"System.Configuration.Assemblies",
			System.Configuration.Assemblies,
			["AssemblyHashAlgorithm", "AssemblyVersionCompatibility"],
			)


if __name__ == '__main__':
	build_stubs()



from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Type

import System
import System.Collections
import System.Configuration
import System.Configuration.Assemblies
import System.Data
import System.Globalization
import System.Reflection
import System.Runtime
import System.Runtime.CompilerServices
import System.Runtime.InteropServices
import System.Runtime.Remoting
import System.Runtime.Serialization
import System.Security
import System.Security.AccessControl
import System.Security.Cryptography
import System.Security.Cryptography.X509Certificates
import System.Security.Policy
import System.Threading
import System.Threading.Tasks
import System.Xml
import System.Xml.Schema
import System.Xml.Serialization
from System.ComponentModel import MarshalByValueComponent


class Stream:

    def BeginRead(self,
            _: List[bytes],
            __: int,
            ___: int,
            ____: Any,
            _____: object,
            ) -> Any: ...

    def BeginWrite(self,
            _: List[bytes],
            __: int,
            ___: int,
            ____: Any,
            _____: object,
            ) -> Any: ...

    @property
    def CanRead(self): ...

    @CanRead.setter
    def CanRead(self): ...

    @property
    def CanSeek(self): ...

    @CanSeek.setter
    def CanSeek(self): ...

    @property
    def CanTimeout(self): ...

    @CanTimeout.setter
    def CanTimeout(self): ...

    @property
    def CanWrite(self): ...

    @CanWrite.setter
    def CanWrite(self): ...

    def Close(self) -> None: ...

    def CopyTo(self, _: Stream, __: int) -> None: ...

    def CopyToAsync(self,
            _: Stream,
            __: int,
            ___: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task: ...

    def CreateObjRef(self, _: Type) -> System.Runtime.Remoting.ObjRef: ...

    def CreateWaitHandle(self) -> System.Threading.WaitHandle: ...

    def Dispose(self, _: bool) -> None: ...

    def EndRead(self, _: Any) -> int: ...

    def EndWrite(self, _: Any) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Flush(self) -> None: ...

    def FlushAsync(self,
            _: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task: ...

    def GetHashCode(self) -> int: ...

    def GetLifetimeService(self) -> object: ...

    def GetType(self) -> Type: ...

    def InitializeLifetimeService(self) -> object: ...

    @property
    def Length(self): ...

    @Length.setter
    def Length(self): ...

    def MemberwiseClone(self) -> object: ...

    def Null(self, *args, **kwargs) -> Any: ...

    def ObjectInvariant(self) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Position(self): ...

    @Position.setter
    def Position(self): ...

    def Read(self, _: List[bytes], __: int, ___: int) -> int: ...

    def ReadAsync(self,
            _: List[bytes],
            __: int,
            ___: int,
            ____: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task: ...

    def ReadByte(self) -> int: ...

    @property
    def ReadTimeout(self): ...

    @ReadTimeout.setter
    def ReadTimeout(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Seek(self, _: int, __: SeekOrigin) -> int: ...

    def SetLength(self, _: int) -> None: ...

    def Synchronized(self, _: Stream) -> Stream: ...

    def ToString(self) -> str: ...

    def Write(self, _: List[bytes], __: int, ___: int) -> None: ...

    def WriteAsync(self,
            _: List[bytes],
            __: int,
            ___: int,
            ____: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task: ...

    def WriteByte(self, _: bytes) -> None: ...

    @property
    def WriteTimeout(self): ...

    @WriteTimeout.setter
    def WriteTimeout(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_CanRead(self) -> bool: ...

    def get_CanSeek(self) -> bool: ...

    def get_CanTimeout(self) -> bool: ...

    def get_CanWrite(self) -> bool: ...

    def get_Length(self) -> int: ...

    def get_Position(self) -> int: ...

    def get_ReadTimeout(self) -> int: ...

    def get_WriteTimeout(self) -> int: ...

    def set_Position(self, _: int) -> None: ...

    def set_ReadTimeout(self, _: int) -> None: ...

    def set_WriteTimeout(self, _: int) -> None: ...


class TextReader:

    def Close(self) -> None: ...

    def CreateObjRef(self, _: Type) -> System.Runtime.Remoting.ObjRef: ...

    def Dispose(self, _: bool) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def GetHashCode(self) -> int: ...

    def GetLifetimeService(self) -> object: ...

    def GetType(self) -> Type: ...

    def InitializeLifetimeService(self) -> object: ...

    def MemberwiseClone(self) -> object: ...

    def Null(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Peek(self) -> int: ...

    def Read(self, _: List[str], __: int, ___: int) -> int: ...

    def ReadAsync(self,
            _: List[str],
            __: int,
            ___: int,
            ) -> System.Threading.Tasks.Task: ...

    def ReadBlock(self, _: List[str], __: int, ___: int) -> int: ...

    def ReadBlockAsync(self,
            _: List[str],
            __: int,
            ___: int,
            ) -> System.Threading.Tasks.Task: ...

    def ReadLine(self) -> str: ...

    def ReadLineAsync(self) -> System.Threading.Tasks.Task[str]: ...

    def ReadToEnd(self) -> str: ...

    def ReadToEndAsync(self) -> System.Threading.Tasks.Task[str]: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Synchronized(self, _: TextReader) -> TextReader: ...

    def ToString(self) -> str: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class SeekOrigin:

    def Begin(self, *args, **kwargs) -> Any: ...

    def CompareTo(self, _: object) -> int: ...

    def Current(self, *args, **kwargs) -> Any: ...

    def End(self, *args, **kwargs) -> Any: ...

    def Equals(self, _: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Format(self, _: Type, __: object, ___: str) -> str: ...

    def GetHashCode(self) -> int: ...

    def GetName(self, _: Type, __: object) -> str: ...

    def GetNames(self, _: Type) -> List[str]: ...

    def GetType(self) -> Type: ...

    def GetTypeCode(self) -> Any: ...

    def GetUnderlyingType(self, _: Type) -> Type: ...

    def GetValues(self, _: Type) -> List: ...

    def HasFlag(self, _: Enum) -> bool: ...

    def IsDefined(self, _: Type, __: object) -> bool: ...

    def MemberwiseClone(self) -> object: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def Parse(self, _: Type, __: str, ___: bool) -> object: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def ToObject(self, _: Type, __: object) -> object: ...

    def ToString(self, _: str, __: Any) -> str: ...

    def TryParse(self, *args, **kwargs) -> Any: ...

    def __init__(self, *args, **kwargs) -> Any: ...


class FileStream:

    def BeginRead(self,
            _: List[bytes],
            __: int,
            ___: int,
            ____: Any,
            _____: object,
            ) -> Any: ...

    def BeginWrite(self,
            _: List[bytes],
            __: int,
            ___: int,
            ____: Any,
            _____: object,
            ) -> Any: ...

    @property
    def CanRead(self): ...

    @CanRead.setter
    def CanRead(self): ...

    @property
    def CanSeek(self): ...

    @CanSeek.setter
    def CanSeek(self): ...

    @property
    def CanTimeout(self): ...

    @CanTimeout.setter
    def CanTimeout(self): ...

    @property
    def CanWrite(self): ...

    @CanWrite.setter
    def CanWrite(self): ...

    def Close(self) -> None: ...

    def CopyTo(self, _: Stream, __: int) -> None: ...

    def CopyToAsync(self,
            _: Stream,
            __: int,
            ___: System.Threading.CancellationToken,
            ) -> System.Threading.Tasks.Task: ...

    def CreateObjRef(self, _: Type) -> System.Runtime.Remoting.ObjRef: ...

    def CreateWaitHandle(self) -> System.Threading.WaitHandle: ...

    def Dispose(self) -> None: ...

    def EndRead(self, _: Any) -> int: ...

    def EndWrite(self, _: Any) -> None: ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Flush(self, _: bool) -> None: ...

    def FlushAsync(self) -> System.Threading.Tasks.Task: ...

    def GetAccessControl(self) -> System.Security.AccessControl.FileSecurity: ...

    def GetHashCode(self) -> int: ...

    def GetLifetimeService(self) -> object: ...

    def GetType(self) -> Type: ...

    @property
    def Handle(self): ...

    @Handle.setter
    def Handle(self): ...

    def InitializeLifetimeService(self) -> object: ...

    @property
    def IsAsync(self): ...

    @IsAsync.setter
    def IsAsync(self): ...

    @property
    def Length(self): ...

    @Length.setter
    def Length(self): ...

    def Lock(self, _: int, __: int) -> None: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def Name(self): ...

    @Name.setter
    def Name(self): ...

    def Null(self, *args, **kwargs) -> Any: ...

    def ObjectInvariant(self) -> None: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    @property
    def Position(self): ...

    @Position.setter
    def Position(self): ...

    def Read(self, _: List[bytes], __: int, ___: int) -> int: ...

    def ReadAsync(self,
            _: List[bytes],
            __: int,
            ___: int,
            ) -> System.Threading.Tasks.Task: ...

    def ReadByte(self) -> int: ...

    @property
    def ReadTimeout(self): ...

    @ReadTimeout.setter
    def ReadTimeout(self): ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    @property
    def SafeFileHandle(self): ...

    @SafeFileHandle.setter
    def SafeFileHandle(self): ...

    def Seek(self, _: int, __: SeekOrigin) -> int: ...

    def SetAccessControl(self, _: System.Security.AccessControl.FileSecurity) -> None: ...

    def SetLength(self, _: int) -> None: ...

    def Synchronized(self, _: Stream) -> Stream: ...

    def ToString(self) -> str: ...

    def Unlock(self, _: int, __: int) -> None: ...

    def Write(self, _: List[bytes], __: int, ___: int) -> None: ...

    def WriteAsync(self,
            _: List[bytes],
            __: int,
            ___: int,
            ) -> System.Threading.Tasks.Task: ...

    def WriteByte(self, _: bytes) -> None: ...

    @property
    def WriteTimeout(self): ...

    @WriteTimeout.setter
    def WriteTimeout(self): ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_CanRead(self) -> bool: ...

    def get_CanSeek(self) -> bool: ...

    def get_CanTimeout(self) -> bool: ...

    def get_CanWrite(self) -> bool: ...

    def get_Handle(self) -> Any: ...

    def get_IsAsync(self) -> bool: ...

    def get_Length(self) -> int: ...

    def get_Name(self) -> str: ...

    def get_Position(self) -> int: ...

    def get_ReadTimeout(self) -> int: ...

    def get_SafeFileHandle(self) -> Any: ...

    def get_WriteTimeout(self) -> int: ...

    def set_Position(self, _: int) -> None: ...

    def set_ReadTimeout(self, _: int) -> None: ...

    def set_WriteTimeout(self, _: int) -> None: ...


class TextWriter:

    def Close(self) -> None: ...

    def CreateObjRef(self, _: Type) -> System.Runtime.Remoting.ObjRef: ...

    def Dispose(self, _: bool) -> None: ...

    @property
    def Encoding(self): ...

    @Encoding.setter
    def Encoding(self): ...

    def Equals(self, _: object, __: object) -> bool: ...

    def Finalize(self) -> None: ...

    def Flush(self) -> None: ...

    def FlushAsync(self) -> System.Threading.Tasks.Task: ...

    @property
    def FormatProvider(self): ...

    @FormatProvider.setter
    def FormatProvider(self): ...

    def GetHashCode(self) -> int: ...

    def GetLifetimeService(self) -> object: ...

    def GetType(self) -> Type: ...

    def InitializeLifetimeService(self) -> object: ...

    def MemberwiseClone(self) -> object: ...

    @property
    def NewLine(self): ...

    @NewLine.setter
    def NewLine(self): ...

    def Null(self, *args, **kwargs) -> Any: ...

    def Overloads(self, *args, **kwargs) -> Any: ...

    def ReferenceEquals(self, _: object, __: object) -> bool: ...

    def Synchronized(self, _: TextWriter) -> TextWriter: ...

    def ToString(self) -> str: ...

    def Write(self, _: str, __: object, ___: object, ____: object) -> None: ...

    def WriteAsync(self, _: str) -> System.Threading.Tasks.Task: ...

    def WriteLine(self, _: str, __: object, ___: object, ____: object) -> None: ...

    def WriteLineAsync(self, _: str) -> System.Threading.Tasks.Task: ...

    def __init__(self, *args, **kwargs) -> Any: ...

    def get_Encoding(self) -> Any: ...

    def get_FormatProvider(self) -> Any: ...

    def get_NewLine(self) -> str: ...

    def set_NewLine(self, _: str) -> None: ...
